=============================
nekrobox
=============================

.. image:: https://badge.fury.io/py/nekrobox.png
    :target: http://badge.fury.io/py/nekrobox
    
.. image:: https://travis-ci.org/Nekroze/nekrobox.png?branch=master
        :target: https://travis-ci.org/Nekroze/nekrobox

.. image:: https://pypip.in/d/nekrobox/badge.png
        :target: https://crate.io/packages/nekrobox?version=latest


A utilities library by Nekroze. The idea is to provide general purpose
utilities for free usage.

Quickstart
----------

Install nekrobox at the command line using pip or easy_install::

    $ pip install nekrobox
    $ easy_install nekrobox

Then use it in a project by simply importing it::

    import nekrobox

Features
--------

* Decorator to help generate sphinx compatible docstrings
